from setuptools import setup, find_packages

setup (
    name = 'tuibox',
    version = '1.0',
    author = 'hlaxman',
    author_email = "harshu8310@gmail.com",
    packages = find_packages(),
    )
